StateView

Struct StateView 

pub struct StateView<'a, S: UserState> { /* private fields */ }
Read-only view into engine state at a single point in time.

This type is used by:

  • observers
  • logging systems
  • extensions
  • external monitoring hooks

It provides safe immutable access without exposing ownership of the underlying State<S>.

Implementations

Source

impl<'a, S> StateView<'a, S>
where S: UserState, <S as UserState>::Float: FloatCore,

pub fn iteration(&self) -> usize

Current iteration number of the engine.

pub fn duration(&self) -> Duration

Total elapsed execution duration.

pub fn best_measure(&self) -> S::Float

Best convergence value observed so far.

pub fn current_measure(&self) -> S::Float

Current convergence value.

pub fn iterations_since_best(&self) -> usize

Number of iterations since the last improvement.

pub fn user<'b>(&'b self) -> &'a S

Access to user-defined state (read-only).