pub struct Tracer { /* private fields */ }Expand description
Structured tracing observer for engine execution.
This observer emits lifecycle and progress events using the tracing
ecosystem. It is designed to remain thin and not interpret numerical
semantics beyond formatting.
Implementations